from app import db
from app.Site.models import Site
from app.Site.schemas import site_schema
from flask import jsonify, make_response, request
import base64

def load_data(schemaArray):
    loaded_site_data = site_schema.load(schemaArray)
    new_site = Site(**loaded_site_data)
    return new_site
def handle_db_commit(result, action='action_type'):
    message_type= {
        'create' : 'Site added successfully',
        'update' : 'Site updated successfully',
        'delete' : 'Site deleted successfully'
    }
    try:
        if action == 'create':
            db.session.add(result)
        elif action == 'delete':
            db.session.delete(result)
        db.session.commit()
        message = message_type.get(action, 'successfully')
        return make_response(jsonify({'message': message, 'status':'Success'}), 200)
    except Exception as e:
        return make_response(jsonify({'message': f'Error{e}', 'status':'error'}), 500)

def get_paginated_result(default_page = 1, default_per_page = 10):
    page = request.args.get('page', default_page, type=int)
    per_page = request.args.get('per_page', default_per_page, type=int)
    return page, per_page
def apply_search_filter(sites_query, search):
    if search:
        sites_query = sites_query.filter(Site.site_name.ilike(f'%{search}%'))
    return sites_query
def paginated_query(query, page, per_page):
    paginated_results = query.paginate(page=page, per_page=per_page, error_out=False)
    total_count = paginated_results.total
    total_pages = paginated_results.pages
    start_index = (page - 1) * per_page + 1
    end_index = min(page * per_page, total_count)
    paginated_data = {
        'total_count' : total_count,
        'total_pages' : total_pages,
        'start_index' : start_index,
        'end_index' : end_index,
        'page' : page
    }
    return paginated_results.items, paginated_data
def serialized_site(site):
    if site.siteImg:
        img_binary = base64.b64decode(site.siteImg)
        img_base64 = base64.b64encode(img_binary)
        site_img_base64 = img_base64.decode()
    else:
        site_img_base64 = None
    return {
        'id': site.site_id,
        'customer_id': site.customer_id,
        'site_name': site.site_name,
        'address': site.address,
        'siteImg': site_img_base64,
        'siteImg_content_type': site.img_content_type,
        'latitude': site.latitude,
        'longitude': site.longitude,
        'status': site.status,
    } 